@@ -1,9 +1,9 @@
 ;;; ecb-face.el --- all face-options of ECB
 
-;; Copyright (C) 2000, 2001 Jesper Nordenberg
+;; Copyright (C) 2000, 2001 Jesper Nordenberg, Klaus Berndl
 
 ;; Author: Klaus Berndl <klaus.berndl@sdm.de>
-;; Maintainer: Jesper Nordenberg <mayhem@home.se>
+;; Maintainer: Klaus Berndl <klaus.berndl@sdm.de>
 ;; Keywords: java, class, browser
 ;; Created: Feb 2002
 
@@ -20,11 +20,23 @@
 ;; GNU Emacs; see the file COPYING.  If not, write to the Free Software
 ;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
+;; $Id: ecb-face.el,v 1.4 2003/03/27 16:13:48 berndl Exp $
+
 ;;; Commentary:
 
 ;; This file contains all options with type 'face and all face-definitions of
 ;; ECB.
 
+;;; History
+;;
+;; For the ChangeLog of this file see the CVS-repository. For a complete
+;; history of the ECB-package see the file NEWS.
+
+;;; Code
+
+(eval-when-compile
+  (require 'silentcomp))
+
 (defgroup ecb-face-options nil
   "Settings for all faces used in ECB."
   :group 'ecb
@@ -50,35 +62,35 @@ The parameters are set for the following display-types:
                                      FG-DARK-COL, BG-DARK-COL
 - t: HEIGHT, BOLD-P, ITALIC-P, INHERIT, FG-REST, BG-REST, REVERSE-VIDEO."
   `(list (list '((class color) (background light))
-               (append (if (and ,height running-emacs-21) (list :height ,height))
-                       (if ,bold-p (if running-emacs-21
+               (append (if (and ,height ecb-running-emacs-21) (list :height ,height))
+                       (if ,bold-p (if ecb-running-emacs-21
                                        (list :weight 'bold)
                                      (list :bold t)))
-                       (if ,italic-p (if running-emacs-21
+                       (if ,italic-p (if ecb-running-emacs-21
                                          (list :slant 'italic)
                                        (list :italic t)))
-                       (if (and ,inherit running-emacs-21) (list :inherit ,inherit))
+                       (if (and ,inherit ecb-running-emacs-21) (list :inherit ,inherit))
                        (if ,fg-light-col (list :foreground ,fg-light-col))
                        (if ,bg-light-col (list :background ,bg-light-col))))
          (list '((class color) (background dark))
-               (append (if (and ,height running-emacs-21) (list :height ,height))
-                       (if ,bold-p (if running-emacs-21
+               (append (if (and ,height ecb-running-emacs-21) (list :height ,height))
+                       (if ,bold-p (if ecb-running-emacs-21
                                        (list :weight 'bold)
                                      (list :bold t)))
-                       (if ,italic-p (if running-emacs-21
+                       (if ,italic-p (if ecb-running-emacs-21
                                          (list :slant 'italic)
                                        (list :italic t)))
-                       (if (and ,inherit running-emacs-21) (list :inherit ,inherit))
+                       (if (and ,inherit ecb-running-emacs-21) (list :inherit ,inherit))
                        (if ,fg-dark-col (list :foreground ,fg-dark-col))
                        (if ,bg-dark-col (list :background ,bg-dark-col))))
-         (list 't (append (if (and ,height running-emacs-21) (list :height ,height))
-                          (if ,bold-p (if running-emacs-21
+         (list 't (append (if (and ,height ecb-running-emacs-21) (list :height ,height))
+                          (if ,bold-p (if ecb-running-emacs-21
                                           (list :weight 'bold)
                                         (list :bold t)))
-                          (if ,italic-p (if running-emacs-21
+                          (if ,italic-p (if ecb-running-emacs-21
                                             (list :slant 'italic)
                                           (list :italic t)))
-                          (if (and ,inherit running-emacs-21) (list :inherit ,inherit))
+                          (if (and ,inherit ecb-running-emacs-21) (list :inherit ,inherit))
                           (if ,fg-rest (list :foreground ,fg-rest))
                           (if ,bg-rest (list :foreground ,bg-rest))
                           (if ,reverse-video-p (list :reverse-video t))))))
@@ -112,7 +124,9 @@ color etc."
   "*Basic face for the ECB directories buffer. This defines the basic
 face the whole directory buffer should displayed with. If the face
 'ecb-default-general-face' is used then the display of all ECB-tree-buffers
-can be changed by modifying only the face 'ecb-default-general-face'."
+can be changed by modifying only the face 'ecb-default-general-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-directories
   :type '(radio (const :tag "Use ecb-default-general-face"
@@ -129,9 +143,11 @@ color etc."
 
 (defcustom ecb-sources-general-face 'ecb-default-general-face
   "*Basic face for the ECB sources buffer. This defines the basic
-face the whole directory buffer should displayed with. If the face
+face the whole sources buffer should displayed with. If the face
 'ecb-default-general-face' is used then the display of all ECB-tree-buffers
-can be changed by modifying only the face 'ecb-default-general-face'."
+can be changed by modifying only the face 'ecb-default-general-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-sources
   :type 'face
@@ -149,9 +165,11 @@ color etc."
 
 (defcustom ecb-methods-general-face 'ecb-default-general-face
   "*Basic face for the ECB methods buffer. This defines the basic
-face the whole directory buffer should displayed with. If the face
+face the whole methods buffer should displayed with. If the face
 'ecb-default-general-face' is used then the display of all ECB-tree-buffers
-can be changed by modifying only the face 'ecb-default-general-face'."
+can be changed by modifying only the face 'ecb-default-general-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-methods
   :type '(radio (const :tag "Use ecb-default-general-face"
@@ -168,9 +186,11 @@ color etc."
 
 (defcustom ecb-history-general-face 'ecb-default-general-face
   "*Basic face for the ECB directory buffer. This defines the basic
-face the whole directory buffer should displayed with. If the face
+face the whole history buffer should displayed with. If the face
 'ecb-default-general-face' is used then the display of all ECB-tree-buffers
-can be changed by modifying only the face 'ecb-default-general-face'."
+can be changed by modifying only the face 'ecb-default-general-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-history
   :type '(radio (const :tag "Use ecb-default-general-face"
@@ -215,7 +235,9 @@ directories buffer."
   "*Face used for highlighting current directory in the directories
 buffer. If the face 'ecb-default-highlight-face' is used then the display of
 all ECB-tree-buffers can be changed by modifying only the face
-'ecb-default-highlight-face'."
+'ecb-default-highlight-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-directories
   :type '(radio (const :tag "Use ecb-default-highlight-face"
@@ -236,7 +258,9 @@ sources buffer."
   "*Face used for highlighting current source in the sources buffer.
 If the face 'ecb-default-highlight-face' is used then the display of all
 ECB-tree-buffers can be changed by modifying only the face
-'ecb-default-highlight-face'."
+'ecb-default-highlight-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-sources
   :type '(radio (const :tag "Use ecb-default-highlight-face"
@@ -257,7 +281,9 @@ in the methods buffer."
   "*Face used for highlighting current method, class or variable in the
 methods buffer. If the face 'ecb-default-highlight-face' is used then the
 display of all ECB-tree-buffers can be changed by modifying only the face
-'ecb-default-highlight-face'."
+'ecb-default-highlight-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-methods
   :type '(radio (const :tag "Use ecb-default-highlight-face"
@@ -278,7 +304,9 @@ history buffer."
   "*Face used for highlighting current history-entry in the history
 buffer. If the face 'ecb-default-highlight-face' is used then the display of
 all ECB-tree-buffers can be changed by modifying only the face
-'ecb-default-highlight-face'."
+'ecb-default-highlight-face'.
+
+Changes take first effect after finishing and reactivating ECB!"
   :group 'ecb-face-options
   :group 'ecb-history
   :type '(radio (const :tag "Use ecb-default-highlight-face"
@@ -337,21 +365,28 @@ it by clicking onto a node in the methods buffer."
   :group 'ecb-faces)
 
 (defface ecb-type-token-group-face (ecb-face-default nil t nil nil
-                                                     (if running-xemacs
+                                                     (if ecb-running-xemacs
                                                          "dimgray"
                                                        "dim gray")
-                                                     (if running-xemacs
+                                                     (if ecb-running-xemacs
                                                          "dimgray"
                                                        "dim gray"))
   "*Define face used with option `ecb-type-token-display'."
   :group 'ecb-faces)
 
-(defface ecb-bucket-token-face (ecb-face-default nil t)
-  "*Face which can be used for displaying bucket tokens in the methods
-buffer. See also `ecb-bucket-token-display'."
-  :group 'ecb-faces)
+(defface ecb-bucket-token-face (ecb-face-default nil t nil
+                                                 'ecb-default-general-face)
+  "*Face used for displaying bucket tokens in the methods
+buffer. See also `ecb-bucket-token-display'.
 
+In GNU Emacs 21.X this face inherits from the face 'ecb-default-general-face'.
 
-(provide 'ecb-face)
+With XEmacs and GNU Emacs 20.X there is no inheritance-feature so if the
+buckets in the ECB-methods-buffer should be displayed with the same basic
+attributes set by 'ecb-default-general-face' this set of basic attributes have
+to be set in 'ecb-bucket-token-face' too!"
+:group 'ecb-faces)
+
+(silentcomp-provide 'ecb-face)
 
 ;;; ecb-face.el ends here
